@@ -7,7 +7,7 @@
  * See http://mod-qos.sourceforge.net/ for further
  * details.
  *
- * Copyright (C) 2017 Pascal Buchbinder
+ * Copyright (C) 2018 Pascal Buchbinder
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -26,7 +26,7 @@
  *
  */
 
-static const char revision[] = "$Id: qsfilter2.c,v 1.83 2017-06-29 05:24:33 pbuchbinder Exp $";
+static const char revision[] = "$Id: qsfilter2.c 2501 2018-10-24 16:22:48Z pbuchbinder $";
 
 /* system */
 #include <stdio.h>
@@ -528,7 +528,7 @@ static void usage(char *cmd, int man) {
   } else {
     printf("Sample Usage and Output\n");
   }
-  qs_man_println(man, "  ./%s -i loc.txt -c httpd.conf -m -e\n", cmd);
+  qs_man_println(man, "  %s -i loc.txt -c httpd.conf -m -e\n", cmd);
   qs_man_println(man, "  ...\n");
   qs_man_println(man, "  # ADD line 1: /aaa/index.do\n");
   qs_man_println(man, "  # 003 ^(/[a-zA-Z0-9\\-_]+)+[/]?\\.?[a-zA-Z]{0,4}$\n");
@@ -545,7 +545,7 @@ static void usage(char *cmd, int man) {
   printf("\n");
   if(man) {
     printf(".SH SEE ALSO\n");
-    printf("qsexec(1), qsgeo(1), qsgrep(1), qshead(1), qslog(1), qslogger(1), qspng(1), qsrotate(1), qssign(1), qstail(1)\n");
+    printf("qsdt(1), qsexec(1), qsgeo(1), qsgrep(1), qshead(1), qslog(1), qslogger(1), qspng(1), qsre(1), qsrespeed(1), qsrotate(1), qssign(1), qstail(1)\n");
     printf(".SH AUTHOR\n");
     printf("Pascal Buchbinder, http://mod-qos.sourceforge.net/\n");
   } else {
