@@ -8,7 +8,7 @@
  * See http://mod-qos.sourceforge.net/ for further
  * details.
  *
- * Copyright (C) 2017 Pascal Buchbinder
+ * Copyright (C) 2018 Pascal Buchbinder
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -27,7 +27,7 @@
  *
  */
 
-static const char revision[] = "$Id: qsgeo.c,v 1.25 2017-06-29 05:24:33 pbuchbinder Exp $";
+static const char revision[] = "$Id: qsgeo.c 2501 2018-10-24 16:22:48Z pbuchbinder $";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -214,21 +214,21 @@ static void usage(const char *cmd, int man) {
   printf("\n");
   if(man) {
     printf(".SH EXAMPLE\n");
-    printf("Reading the file access_log and adding the country code to the IP address field:\n");
+    printf("Reading the file access.log and adding the country code to the IP address field:\n");
     printf("\n");
   } else {
-    printf("Example reading the file access_log and adding the country code to\n");
+    printf("Example reading the file access.log and adding the country code to\n");
     printf("the IP address field:\n");
   }
-  qs_man_println(man, "  cat access_log | %s -d GeoIPCountryWhois.csv\n", cmd);
+  qs_man_println(man, "  cat access.log | %s -d GeoIPCountryWhois.csv\n", cmd);
   printf("\n");
   if(man) {
-    printf("Reading the file access_log and showing a summary only:\n");
+    printf("Reading the file access.log and showing a summary only:\n");
     printf("\n");
   } else {
-    printf("Example reading the file access_log and showing a summary only:\n");
+    printf("Example reading the file access.log and showing a summary only:\n");
   }
-  qs_man_println(man, "  cat access_log | %s -d GeoIPCountryWhois.csv -s\n", cmd);
+  qs_man_println(man, "  cat access.log | %s -d GeoIPCountryWhois.csv -s\n", cmd);
   printf("\n");
   if(man) {
     printf("Resolving a single IP address:\n");
@@ -240,7 +240,7 @@ static void usage(const char *cmd, int man) {
   printf("\n");
   if(man) {
     printf(".SH SEE ALSO\n");
-    printf("qsexec(1), qsfilter2(1), qsgrep(1), qshead(1), qslog(1), qslogger(1), qspng(1), qsrotate(1), qssign(1), qstail(1)\n");
+    printf("qsdt(1), qsexec(1), qsfilter2(1), qsgrep(1), qshead(1), qslog(1), qslogger(1), qspng(1), qsre(1), qsrespeed(1), qsrotate(1), qssign(1), qstail(1)\n");
     printf(".SH AUTHOR\n");
     printf("Pascal Buchbinder, http://mod-qos.sourceforge.net/\n");
   } else {
@@ -360,8 +360,10 @@ static qos_geo_t *qos_loadgeo(apr_pool_t *pool, const char *db, int *size, char
 	g->c[0] = '\0';
         if(m_inject) {
           if(inj->start && (g->start > inj->start)) {
-            printf("%s\n", inj->c);
-            inj++;
+            while(inj->start && (g->start > inj->start)) {
+              printf("%s\n", inj->c);
+              inj++;
+            }
           } else if(g->start != inj->start) {
             if(missingAddr) {
               /* some databases do not include IP address 
