@@ -27,7 +27,7 @@
  *
  */
 
-static const char revision[] = "$Id: qslogger.c 2348 2018-01-03 21:14:27Z pbuchbinder $";
+static const char revision[] = "$Id: qslogger.c 2501 2018-10-24 16:22:48Z pbuchbinder $";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -296,11 +296,11 @@ static void usage(const char *cmd, int man) {
   } else {
     printf("Example:\n");
   }
-  qs_man_println(man, "  ErrorLog \"|./%s -t apache -f local7\"\n", cmd);
+  qs_man_println(man, "  ErrorLog \"|/usr/bin/%s -t apache -f local7\"\n", cmd);
   printf("\n");
   if(man) {
     printf(".SH SEE ALSO\n");
-    printf("qsexec(1), qsfilter2(1), qsgeo(1), qsgrep(1), qshead(1), qslog(1), qspng(1), qsrotate(1), qssign(1), qstail(1)\n");
+    printf("qsdt(1), qsexec(1), qsfilter2(1), qsgeo(1), qsgrep(1), qshead(1), qslog(1), qspng(1), qsre(1), qsrespeed(1), qsrotate(1), qssign(1), qstail(1)\n");
     printf(".SH AUTHOR\n");
     printf("Pascal Buchbinder, http://mod-qos.sourceforge.net/\n");
   } else {
