@@ -9,7 +9,7 @@
  * See http://mod-qos.sourceforge.net/ for further
  * details.
  *
- * Copyright (C) 2017 Pascal Buchbinder
+ * Copyright (C) 2018 Pascal Buchbinder
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -27,7 +27,7 @@
  * limitations under the License.
  */
 
-static const char revision[] = "$Id: qstail.c,v 1.19 2017-06-29 05:24:33 pbuchbinder Exp $";
+static const char revision[] = "$Id: qstail.c 2486 2018-09-03 20:22:17Z pbuchbinder $";
 
 #include <stdio.h>
 #include <unistd.h>
@@ -83,7 +83,7 @@ static void usage(char *cmd, int man) {
   printf("\n");
   if(man) {
     printf(".SH SEE ALSO\n");
-    printf("qsexec(1), qsfilter2(1), qsgeo(1), qsgrep(1), qshead(1), qslog(1), qslogger(1), qspng(1), qsrotate(1), qssign(1)\n");
+    printf("qsdt(1), qsexec(1), qsfilter2(1), qsgeo(1), qsgrep(1), qshead(1), qslog(1), qslogger(1), qspng(1), qsre(1), qsrespeed(1), qsrotate(1), qssign(1)\n");
     printf(".SH AUTHOR\n");
     printf("Pascal Buchbinder, http://mod-qos.sourceforge.net/\n");
   } else {
